using System;
using System.Data;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace EntLibQuickStarts
{
	public sealed class Customers
	{
		private Customers() {}

		/// <summary>
		/// Inserts a record into the Customers table.
		/// </summary>
		public static int Insert(string name, string address, string city, string country, string postalCode)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleCustomersInsert");

			myCommand.AddInParameter("@Name", DbType.String, name);
			myCommand.AddInParameter("@Address", DbType.String, address);
			myCommand.AddInParameter("@City", DbType.String, city);
			myCommand.AddInParameter("@Country", DbType.String, country);
			myCommand.AddInParameter("@PostalCode", DbType.String, postalCode);

			// Execute the query and return the new identity value
			return Convert.ToInt32(myDatabase.ExecuteScalar(myCommand));
		}

		/// <summary>
		/// Updates a record in the Customers table.
		/// </summary>
		public static void Update(int customerID, string name, string address, string city, string country, string postalCode)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleCustomersUpdate");

			myCommand.AddInParameter("@CustomerID", DbType.Int32, customerID);
			myCommand.AddInParameter("@Name", DbType.String, name);
			myCommand.AddInParameter("@Address", DbType.String, address);
			myCommand.AddInParameter("@City", DbType.String, city);
			myCommand.AddInParameter("@Country", DbType.String, country);
			myCommand.AddInParameter("@PostalCode", DbType.String, postalCode);

			myDatabase.ExecuteNonQuery(myCommand);
		}

		/// <summary>
		/// Deletes a record from the Customers table by a composite primary key.
		/// </summary>
		public static void Delete(int customerID)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleCustomersDelete");

			myCommand.AddInParameter("@CustomerID", DbType.Int32, customerID);

			myDatabase.ExecuteNonQuery(myCommand);
		}

		/// <summary>
		/// Selects a single record from the Customers table.
		/// </summary>
		public static IDataReader Select(int customerID)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleCustomersSelect");

			myCommand.AddInParameter("@CustomerID", DbType.Int32, customerID);

			return myDatabase.ExecuteReader(myCommand);
		}

		/// <summary>
		/// Selects all records from the Customers table.
		/// </summary>
		public static IDataReader SelectAll()
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleCustomersSelectAll");

			return myDatabase.ExecuteReader(myCommand);
		}
	}
}
