using System;
using System.Data;
using Microsoft.Practices.EnterpriseLibrary.Data;

namespace EntLibQuickStarts
{
	public sealed class Products
	{
		private Products() {}

		/// <summary>
		/// Inserts a record into the Products table.
		/// </summary>
		public static int Insert(string productName, int categoryID, decimal unitPrice, DateTime lastUpdate)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleProductsInsert");

			myCommand.AddInParameter("@ProductName", DbType.String, productName);
			myCommand.AddInParameter("@CategoryID", DbType.Int32, categoryID);
			myCommand.AddInParameter("@UnitPrice", DbType.Currency, unitPrice);
			myCommand.AddInParameter("@LastUpdate", DbType.DateTime, lastUpdate);

			// Execute the query and return the new identity value
			return Convert.ToInt32(myDatabase.ExecuteScalar(myCommand));
		}

		/// <summary>
		/// Updates a record in the Products table.
		/// </summary>
		public static void Update(int productID, string productName, int categoryID, decimal unitPrice, DateTime lastUpdate)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleProductsUpdate");

			myCommand.AddInParameter("@ProductID", DbType.Int32, productID);
			myCommand.AddInParameter("@ProductName", DbType.String, productName);
			myCommand.AddInParameter("@CategoryID", DbType.Int32, categoryID);
			myCommand.AddInParameter("@UnitPrice", DbType.Currency, unitPrice);
			myCommand.AddInParameter("@LastUpdate", DbType.DateTime, lastUpdate);

			myDatabase.ExecuteNonQuery(myCommand);
		}

		/// <summary>
		/// Deletes a record from the Products table by a composite primary key.
		/// </summary>
		public static void Delete(int productID)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleProductsDelete");

			myCommand.AddInParameter("@ProductID", DbType.Int32, productID);

			myDatabase.ExecuteNonQuery(myCommand);
		}

		/// <summary>
		/// Selects a single record from the Products table.
		/// </summary>
		public static IDataReader Select(int productID)
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleProductsSelect");

			myCommand.AddInParameter("@ProductID", DbType.Int32, productID);

			return myDatabase.ExecuteReader(myCommand);
		}

		/// <summary>
		/// Selects all records from the Products table.
		/// </summary>
		public static IDataReader SelectAll()
		{
			Database myDatabase = DatabaseFactory.CreateDatabase();
			DBCommandWrapper myCommand = myDatabase.GetStoredProcCommandWrapper("SampleProductsSelectAll");

			return myDatabase.ExecuteReader(myCommand);
		}
	}
}
